@@ -671,6 +671,9 @@ const completion: Fig.Spec = {
         {
           name: "--sheet",
         },
+        {
+          name: "--header-row",
+        },
         {
           name: "--metadata",
         },
@@ -689,6 +692,9 @@ const completion: Fig.Spec = {
         {
           name: "--keep-zero-time",
         },
+        {
+          name: "--table",
+        },
         {
           name: "--range",
         },
