@@ -30,8 +30,10 @@ pub mod join;
 pub mod joinp;
 pub mod json;
 pub mod jsonl;
+pub mod lens;
 pub mod luau;
 pub mod partition;
+pub mod pro;
 pub mod prompt;
 pub mod pseudo;
 pub mod python;
