@@ -286,7 +286,9 @@ apply options:
     -j, --jobs <arg>            The number of jobs to run in parallel.
                                 When not set, the number of jobs is set to the number of CPUs detected.
     -b, --batch <size>          The number of rows per batch to load into memory, before running in parallel.
-                                Set to 0 to load all rows in one batch.
+                                Automatically determined for CSV files with more than 50000 rows.
+                                Set to 0 to load all rows in one batch. Set to 1 to force batch optimization
+                                even for files with less than 50000 rows.
                                 [default: 50000]
 
 Common options:
@@ -312,6 +314,7 @@ use gender_guesser::Gender;
 use indicatif::{ProgressBar, ProgressDrawTarget};
 use log::debug;
 use qsv_currency::Currency;
+use qsv_vader_sentiment_analysis::SentimentIntensityAnalyzer;
 use rayon::{
     iter::{IndexedParallelIterator, ParallelIterator},
     prelude::IntoParallelRefIterator,
@@ -325,7 +328,6 @@ use strsim::{
 use strum_macros::EnumString;
 use thousands::{policies, Separable, SeparatorPolicy};
 use titlecase::titlecase;
-use vader_sentiment::SentimentIntensityAnalyzer;
 use whatlang::detect;
 
 use crate::{
@@ -442,13 +444,13 @@ enum ApplySubCmd {
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
-    let rconfig = Config::new(&args.arg_input)
+    let rconfig = Config::new(args.arg_input.as_ref())
         .delimiter(args.flag_delimiter)
         .no_headers(args.flag_no_headers)
         .select(args.arg_column);
 
     let mut rdr = rconfig.reader()?;
-    let mut wtr = Config::new(&args.flag_output).writer()?;
+    let mut wtr = Config::new(args.flag_output.as_ref()).writer()?;
 
     let headers = rdr.byte_headers()?.clone();
     let sel = rconfig.selection(&headers)?;
@@ -492,7 +494,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         dynfmt_fields.sort_unstable();
 
         // now, get the indices of the columns for the lookup vec
-        let (safe_headers, _) = util::safe_header_names(&headers, false, false, &None, "", true);
+        let (safe_headers, _) = util::safe_header_names(&headers, false, false, None, "", true);
         for (i, field) in safe_headers.iter().enumerate() {
             if dynfmt_fields.binary_search(&field.as_str()).is_ok() {
                 let field_with_curly = format!("{{{field}}}");
@@ -513,7 +515,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             &args.arg_operations.split(',').collect(),
             &args.flag_comparand,
             &args.flag_replacement,
-            &args.flag_new_column,
+            args.flag_new_column.as_ref(),
             &args.flag_formatstr,
         ) {
             Ok(operations_vec) => ops_vec = operations_vec,
@@ -566,32 +568,22 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     #[allow(unused_assignments)]
     let mut batch_record = csv::StringRecord::new();
 
+    // set RAYON_NUM_THREADS
+    let num_jobs = util::njobs(args.flag_jobs);
+
     // reuse batch buffers
-    let batchsize: usize = if args.flag_batch == 0 {
-        util::count_rows(&rconfig)? as usize
-    } else {
-        args.flag_batch
-    };
+    let batchsize = util::optimal_batch_size(&rconfig, args.flag_batch, num_jobs);
     let mut batch = Vec::with_capacity(batchsize);
     let mut batch_results = Vec::with_capacity(batchsize);
 
-    // set RAYON_NUM_THREADS
-    util::njobs(args.flag_jobs);
-
     // main loop to read CSV and construct batches for parallel processing.
     // each batch is processed via Rayon parallel iterator.
     // loop exits when batch is empty.
     'batch_loop: loop {
         for _ in 0..batchsize {
             match rdr.read_record(&mut batch_record) {
-                Ok(has_data) => {
-                    if has_data {
-                        batch.push(std::mem::take(&mut batch_record));
-                    } else {
-                        // nothing else to add to batch
-                        break;
-                    }
-                },
+                Ok(true) => batch.push(std::mem::take(&mut batch_record)),
+                Ok(false) => break, // nothing else to add to batch
                 Err(e) => {
                     return fail_clierror!("Error reading file: {e}");
                 },
@@ -732,7 +724,7 @@ fn validate_operations(
     operations: &Vec<&str>,
     flag_comparand: &str,
     flag_replacement: &str,
-    flag_new_column: &Option<String>,
+    flag_new_column: Option<&String>,
     flag_formatstr: &str,
 ) -> Result<Vec<Operations>, CliError> {
     let mut censor_invokes = 0_u8;
@@ -1203,8 +1195,8 @@ fn apply_operations(
             },
             Operations::Sentiment => {
                 // safety: we set SENTIMENT_ANALYZER in validate_operations()
-                let sentiment_analyzer = SENTIMENT_ANALYZER
-                    .get_or_init(vader_sentiment::SentimentIntensityAnalyzer::new);
+                let sentiment_analyzer =
+                    SENTIMENT_ANALYZER.get_or_init(SentimentIntensityAnalyzer::new);
                 let sentiment_scores = sentiment_analyzer.polarity_scores(cell);
                 *cell = sentiment_scores.get("compound").unwrap_or(&0.0).to_string();
             },
