@@ -487,7 +487,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     };
     log::info!("Cache Type: {cache_type:?}");
 
-    let mut rconfig = Config::new(&args.arg_input)
+    let mut rconfig = Config::new(args.arg_input.as_ref())
         .delimiter(args.flag_delimiter)
         .trim(csv::Trim::All)
         .no_headers(args.flag_no_headers);
@@ -496,12 +496,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut wtr = if args.flag_new_column.is_some() {
         // when adding a new column for the response, the output
         // is a regular CSV file
-        Config::new(&args.flag_output).writer()?
+        Config::new(args.flag_output.as_ref()).writer()?
     } else {
         // otherwise, the output is a JSONL file. So we need to configure
         // the csv writer so it doesn't double double quote the JSON response
         // and its flexible (i.e. "column counts are different row to row")
-        Config::new(&args.flag_output)
+        Config::new(args.flag_output.as_ref())
             .quote_style(csv::QuoteStyle::Never)
             .flexible(true)
             .writer()?
@@ -544,7 +544,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         dynfmt_url_template = url_template.to_string();
         // first, get the fields used in the url template
         let (safe_headers, _) =
-            util::safe_header_names(&str_headers, false, false, &None, "", false);
+            util::safe_header_names(&str_headers, false, false, None, "", false);
         let formatstr_re: &'static Regex = regex_oncelock!(r"\{(?P<key>\w+)?\}");
         for format_fields in formatstr_re.captures_iter(url_template) {
             dynfmt_fields.push(format_fields.name("key").unwrap().as_str());
@@ -682,7 +682,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let report_path;
     if report == ReportKind::None {
         // no report, point report_wtr to /dev/null (AKA sink)
-        report_wtr = Config::new(&Some("sink".to_string())).writer()?;
+        report_wtr = Config::new(Some("sink".to_string()).as_ref()).writer()?;
         report_path = String::new();
     } else {
         report_path = args
@@ -690,7 +690,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             .clone()
             .unwrap_or_else(|| "stdin.csv".to_string());
 
-        report_wtr = Config::new(&Some(report_path.clone() + FETCH_REPORT_SUFFIX))
+        report_wtr = Config::new(Some(report_path.clone() + FETCH_REPORT_SUFFIX).as_ref())
             .delimiter(Some(Delimiter(b'\t')))
             .writer()?;
         let mut report_headers = if report == ReportKind::Detailed {
@@ -798,7 +798,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         &url,
                         &client,
                         &limiter,
-                        &jql_selector,
+                        jql_selector.as_ref(),
                         args.flag_store_error,
                         args.flag_pretty,
                         include_existing_columns,
@@ -816,7 +816,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         &url,
                         &client,
                         &limiter,
-                        &jql_selector,
+                        jql_selector.as_ref(),
                         args.flag_store_error,
                         args.flag_pretty,
                         include_existing_columns,
@@ -838,7 +838,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         &url,
                         &client,
                         &limiter,
-                        &jql_selector,
+                        jql_selector.as_ref(),
                         args.flag_store_error,
                         args.flag_pretty,
                         include_existing_columns,
@@ -878,7 +878,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         &url,
                         &client,
                         &limiter,
-                        &jql_selector,
+                        jql_selector.as_ref(),
                         args.flag_store_error,
                         args.flag_pretty,
                         include_existing_columns,
@@ -1025,7 +1025,7 @@ fn get_cached_response(
     url: &str,
     client: &reqwest::blocking::Client,
     limiter: &governor::RateLimiter<NotKeyed, InMemoryState, DefaultClock, NoOpMiddleware>,
-    flag_jql: &Option<String>,
+    flag_jql: Option<&String>,
     flag_store_error: bool,
     flag_pretty: bool,
     include_existing_columns: bool,
@@ -1073,7 +1073,7 @@ fn get_diskcache_response(
     url: &str,
     client: &reqwest::blocking::Client,
     limiter: &governor::RateLimiter<NotKeyed, InMemoryState, DefaultClock, NoOpMiddleware>,
-    flag_jql: &Option<String>,
+    flag_jql: Option<&String>,
     flag_store_error: bool,
     flag_pretty: bool,
     include_existing_columns: bool,
@@ -1123,7 +1123,7 @@ fn get_redis_response(
     url: &str,
     client: &reqwest::blocking::Client,
     limiter: &governor::RateLimiter<NotKeyed, InMemoryState, DefaultClock, NoOpMiddleware>,
-    flag_jql: &Option<String>,
+    flag_jql: Option<&String>,
     flag_store_error: bool,
     flag_pretty: bool,
     include_existing_columns: bool,
@@ -1170,7 +1170,7 @@ fn get_response(
     url: &str,
     client: &reqwest::blocking::Client,
     limiter: &governor::RateLimiter<NotKeyed, InMemoryState, DefaultClock, NoOpMiddleware>,
-    flag_jql: &Option<String>,
+    flag_jql: Option<&String>,
     flag_store_error: bool,
     flag_pretty: bool,
     include_existing_columns: bool,
