@@ -183,12 +183,12 @@ impl From<PyErr> for CliError {
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
-    let rconfig = Config::new(&args.arg_input)
+    let rconfig = Config::new(args.arg_input.as_ref())
         .delimiter(args.flag_delimiter)
         .no_headers(args.flag_no_headers);
 
     let mut rdr = rconfig.reader()?;
-    let mut wtr = Config::new(&args.flag_output).writer()?;
+    let mut wtr = Config::new(args.flag_output.as_ref()).writer()?;
 
     if log_enabled!(Debug) {
         Python::with_gil(|py| {
@@ -238,7 +238,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     }
 
     // ensure col/header names are valid and safe python variables
-    let (header_vec, _) = util::safe_header_names(&headers, true, false, &None, "_", false);
+    let (header_vec, _) = util::safe_header_names(&headers, true, false, None, "_", false);
 
     // amortize memory allocation by reusing record
     #[allow(unused_assignments)]
