@@ -138,7 +138,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .dfa_size_limit(args.flag_dfa_size_limit * (1 << 20))
         .build()?;
 
-    let rconfig = Config::new(&args.arg_input)
+    let rconfig = Config::new(args.arg_input.as_ref())
         .delimiter(args.flag_delimiter)
         .no_headers(args.flag_no_headers)
         .select(args.flag_select);
@@ -152,10 +152,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let flag_not_one = args.flag_not_one;
 
     let mut rdr = rconfig.reader()?;
-    let mut wtr = Config::new(&args.flag_output).writer()?;
+    let mut wtr = Config::new(args.flag_output.as_ref()).writer()?;
 
     let mut json_wtr = if flag_json {
-        util::create_json_writer(&args.flag_output, DEFAULT_WTR_BUFFER_CAPACITY * 4)?
+        util::create_json_writer(args.flag_output.as_ref(), DEFAULT_WTR_BUFFER_CAPACITY * 4)?
     } else {
         Box::new(std::io::sink())
     };
@@ -213,7 +213,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         let mut stderr_wtr = csv::WriterBuilder::new().from_writer(std::io::stderr());
 
         let mut stderr_jsonwtr = if flag_json {
-            util::create_json_writer(&Some("stderr".to_string()), DEFAULT_WTR_BUFFER_CAPACITY * 4)?
+            util::create_json_writer(Some(&"stderr".to_string()), DEFAULT_WTR_BUFFER_CAPACITY * 4)?
         } else {
             Box::new(std::io::sink())
         };
