@@ -116,7 +116,12 @@ impl Args {
                 .skip(start)
                 .take(end - start)
                 .map(|r| r.unwrap());
-            util::write_json(&self.flag_output, self.flag_no_headers, &headers, records)
+            util::write_json(
+                self.flag_output.as_ref(),
+                self.flag_no_headers,
+                &headers,
+                records,
+            )
         } else {
             let mut wtr = self.wconfig().writer()?;
             self.rconfig().write_headers(&mut rdr, &mut wtr)?;
@@ -139,7 +144,12 @@ impl Args {
                 .byte_records()
                 .take(end - start)
                 .map(|r| r.unwrap());
-            util::write_json(&self.flag_output, self.flag_no_headers, &headers, records)
+            util::write_json(
+                self.flag_output.as_ref(),
+                self.flag_no_headers,
+                &headers,
+                records,
+            )
         } else {
             let mut wtr = self.wconfig().writer()?;
             self.rconfig().write_headers(&mut *indexed_file, &mut wtr)?;
@@ -177,12 +187,12 @@ impl Args {
     }
 
     fn rconfig(&self) -> Config {
-        Config::new(&self.arg_input)
+        Config::new(self.arg_input.as_ref())
             .delimiter(self.flag_delimiter)
             .no_headers(self.flag_no_headers)
     }
 
     fn wconfig(&self) -> Config {
-        Config::new(&self.flag_output)
+        Config::new(self.flag_output.as_ref())
     }
 }
