@@ -6,8 +6,8 @@ Polars SQL is a SQL dialect, converting SQL queries to fast Polars LazyFrame exp
 (see https://docs.pola.rs/user-guide/sql/intro/).
 
 For a list of SQL functions and keywords supported by Polars SQL, see
-https://github.com/pola-rs/polars/blob/py-1.8.1/crates/polars-sql/src/functions.rs and
-https://github.com/pola-rs/polars/blob/py-1.8.1/crates/polars-sql/src/keywords.rs.
+https://github.com/pola-rs/polars/blob/ee9bafbdef7d62baa06d469f42e6cec0755eb544/crates/polars-sql/src/functions.rs#L32 and
+https://github.com/pola-rs/polars/blob/ee9bafbdef7d62baa06d469f42e6cec0755eb544/crates/polars-sql/src/keywords.rs.
 https://docs.pola.rs/py-polars/html/reference/sql/index.html also provides a more readable
 version of the SQL functions and keywords, though be aware that it's for the Python version
 of Polars, so there will be some minor syntax differences.
@@ -27,6 +27,11 @@ Example queries:
 
    qsv sqlp data.csv data2.csv 'SELECT col1 FROM data WHERE col1 IN (SELECT col2 FROM data2)'
 
+  # Use dollar-quoting to avoid escaping reserved characters in literals.
+  https://www.postgresql.org/docs/current/sql-syntax-lexical.html#SQL-SYNTAX-DOLLAR-QUOTING 
+   qsv sqlp data.csv "SELECT * FROM data WHERE col1 = $$O'Reilly$$"
+   qsv sqlp data.csv 'SELECT * FROM data WHERE col1 = $SomeTag$Diane's horse "Twinkle"$SomeTag$'
+
   # Unions and Joins are supported.
    qsv sqlp data1.csv data2.csv 'SELECT * FROM data1 UNION ALL BY NAME SELECT * FROM data2'
 
@@ -626,9 +631,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // scanning the entire file with a 0 infer_len which triggers a full table scan.
     args.flag_infer_len =
         if args.flag_infer_len == 0 && !is_sql_script && !skip_input && args.arg_input.len() == 1 {
-            let rconfig = Config::new(&Some(args.arg_input[0].to_string_lossy().to_string()))
-                .delimiter(args.flag_delimiter)
-                .no_headers(false);
+            let rconfig =
+                Config::new(Some(args.arg_input[0].to_string_lossy().to_string()).as_ref())
+                    .delimiter(args.flag_delimiter)
+                    .no_headers(false);
             util::count_rows(&rconfig).unwrap_or(0) as usize
         } else {
             args.flag_infer_len
