@@ -1,5 +1,5 @@
 static USAGE: &str = r#"
-Convert CSV files to PostgreSQL, SQLite, XLSX, Parquet and Data Package.
+Convert CSV files to PostgreSQL, SQLite, XLSX and Data Package.
 
 POSTGRES
 To convert to postgres you need to supply connection string.
@@ -106,32 +106,6 @@ Load files listed in the 'ourdata.infile-list' into xlsx file.
 
     $ qsv to xlsx output.xlsx ourdata.infile-list
 
-PARQUET (only available if compiled with `to_parquet` feature)
-Convert to directory of parquet files.  Need to select a directory, it will be created if it does not exists.
-If the `to_parquet` feature is not enabled, a simpler parquet conversion is available using the `sqlp`
-subcommand with the `--format parquet` option.
-
-To stream the data use the `pipe` option.  To pipe from stdin use `-` for the filename or use named pipe.
-Type guessing is more limited with this option.
-
-Examples:
-
-Convert `file1.csv` and `file2.csv' into `mydir/file1.parquet` and `mydir/file2.parquet` files.
-
-  $ qsv to parquet mydir file1.csv file2.csv
-
-Convert from stdin.
-
-  $ qsv to parquet --pipe mydir -
-
-Convert all files in dir1 into parquet files in myparquetdir.
-
-    $ qsv to parquet myparquetdir dir1
-
-Convert files listed in the 'data.infile-list' into parquet files in myparquetdir.
-    
-        $ qsv to parquet myparquetdir data.infile-list
-
 DATAPACKAGE
 Generate a datapackage, which contains stats and information about what is in the CSV files.
 
@@ -163,7 +137,6 @@ Usage:
     qsv to postgres [options] <postgres> [<input>...]
     qsv to sqlite [options] <sqlite> [<input>...]
     qsv to xlsx [options] <xlsx> [<input>...]
-    qsv to parquet [options] <parquet> [<input>...]
     qsv to datapackage [options] <datapackage> [<input>...]
     qsv to --help
 
@@ -176,7 +149,7 @@ To options:
     -s --schema <arg>      The schema to load the data into. (postgres only).
     -d --drop              Drop tables before loading new data into them (postgres/sqlite only).
     -e --evolve            If loading into existing db, alter existing tables so that new data will load. (postgres/sqlite only).
-    -i --pipe              For parquet, allow piping from stdin (using `-`) or from a named pipe.
+    -i --pipe              Allow piping from stdin (using `-`) or from a named pipe.
     -p --separator <arg>   For xlsx, use this character to help truncate xlsx sheet names.
                            Defaults to space.
     -j, --jobs <arg>       The number of jobs to run in parallel.
@@ -190,8 +163,6 @@ Common options:
 
 use std::{io::Write, path::PathBuf};
 
-#[cfg(all(feature = "to_parquet", feature = "feature_capable"))]
-use csvs_convert::csvs_to_parquet_with_options;
 use csvs_convert::{
     csvs_to_postgres_with_options, csvs_to_sqlite_with_options, csvs_to_xlsx_with_options,
     make_datapackage, DescribeOptions, Options,
@@ -213,8 +184,6 @@ struct Args {
     arg_postgres:       Option<String>,
     cmd_sqlite:         bool,
     arg_sqlite:         Option<String>,
-    cmd_parquet:        bool,
-    arg_parquet:        Option<String>,
     cmd_xlsx:           bool,
     arg_xlsx:           Option<String>,
     cmd_datapackage:    bool,
@@ -296,24 +265,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             )?;
         }
         debug!("conversion to sqlite complete");
-    } else if args.cmd_parquet {
-        #[cfg(all(feature = "to_parquet", feature = "feature_capable"))]
-        {
-            debug!("converting to parquet");
-            arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
-            output = csvs_to_parquet_with_options(
-                args.arg_parquet.expect("checked above"),
-                arg_input,
-                options,
-            )?;
-            debug!("conversion to parquet complete");
-        }
-        #[cfg(not(all(feature = "to_parquet", feature = "feature_capable")))]
-        {
-            return fail_clierror!(
-                "`to_parquet` feature disabled. `to parquet` subcommand not available."
-            );
-        }
     } else if args.cmd_xlsx {
         debug!("converting to xlsx");
         arg_input = process_input(arg_input, &tmpdir, EMPTY_STDIN_ERRMSG)?;
@@ -336,7 +287,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         debug!("datapackage complete");
     } else {
         return fail_clierror!(
-            "Need to supply either xlsx,parquet,postgres,sqlite,datapackage as subcommand"
+            "Need to supply either xlsx,postgres,sqlite,datapackage as subcommand"
         );
     }
 
