@@ -30,10 +30,10 @@ qsv supports a custom format - `currency`. This format will only accept a valid
       Negative amounts: ($100.00) or -$100.00
       Different styles: 1.000,00 (used in some countries for euros)
 
-qsv also supports a custom keyword - `dynenum`. It allows for dynamic validation against a CSV.
-This is useful for validating against a set of values that is not known at the time of schema creation
-or when the set of valid values is dynamic or too large to hardcode into the schema.
-`dynenum` can be used to validate against a CSV file on the local filesystem or on a URL (http/https).
+qsv also supports a custom keyword - `dynamicEnum`. It allows for dynamic validation against a CSV.
+This is useful for validating against a set of values unknown at the time of schema creation or
+when the set of valid values is dynamic or too large to hardcode into the schema.
+`dynamicEnum` can be used to validate against a CSV file on the local filesystem or on a URL (http/https).
 Only the first column of the CSV file is read and used for validation.
 
 You can create a JSON Schema file from a reference CSV file using the `qsv schema` command.
@@ -106,10 +106,13 @@ Validate options:
                                When not set, the number of jobs is set to the
                                number of CPUs detected.
     -b, --batch <size>         The number of rows per batch to load into memory,
-                               before running in parallel. Set to 0 to load all rows in one batch.
-                               [default: 50000]
+                               before running in parallel. Automatically determined
+                               for CSV files with more than 50000 rows.
+                               Set to 0 to load all rows in one batch.
+                               Set to 1 to force batch optimization even for files with
+                               less than 50000 rows. [default: 50000]
     --timeout <seconds>        Timeout for downloading json-schemas on URLs and for
-                               'dynenum' lookups on URLs. [default: 30]
+                               'dynamicEnum' lookups on URLs. [default: 30]
 
 Common options:
     -h, --help                 Display this message
@@ -127,6 +130,7 @@ Common options:
 "#;
 
 use std::{
+    borrow::Cow,
     env,
     fs::File,
     io::{BufReader, BufWriter, Read, Write},
@@ -143,7 +147,6 @@ use csv::ByteRecord;
 use indicatif::HumanCount;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{ProgressBar, ProgressDrawTarget};
-use itertools::Itertools;
 use jsonschema::{
     output::BasicOutput,
     paths::{JsonPointer, JsonPointerNode, PathChunk},
@@ -241,7 +244,6 @@ fn currency_format_checker(s: &str) -> bool {
     })
 }
 
-#[derive(Debug)]
 struct DynEnumValidator {
     dynenum_set: HashSet<String>,
 }
@@ -254,6 +256,7 @@ impl DynEnumValidator {
 }
 
 impl Keyword for DynEnumValidator {
+    #[inline]
     fn validate<'instance>(
         &self,
         instance: &'instance Value,
@@ -266,12 +269,13 @@ impl Keyword for DynEnumValidator {
                 JsonPointer::default(),
                 instance_path.into(),
                 instance,
-                "Value must be a valid dynamic enum",
+                format!("{instance} is not a valid dynamicEnum value"),
             );
             Box::new(once(error))
         }
     }
 
+    #[inline]
     fn is_valid(&self, instance: &Value) -> bool {
         if let Value::String(s) = instance {
             self.dynenum_set.contains(s)
@@ -304,7 +308,7 @@ fn dyn_enum_validator_factory<'a>(
                 None,
             );
             if let Err(e) = tokio::runtime::Runtime::new()?.block_on(future) {
-                return fail_validation_error!("Error downloading dynenum file - {e}");
+                return fail_validation_error!("Error downloading dynamicEnum file - {e}");
             }
 
             temp_download.path().to_str().unwrap().to_string()
@@ -313,14 +317,14 @@ fn dyn_enum_validator_factory<'a>(
             let uri_path = std::path::Path::new(uri);
             let uri_exists = uri_path.exists();
             if !uri_exists {
-                return fail_validation_error!("dynenum file not found - {uri}");
+                return fail_validation_error!("dynamicEnum file not found - {uri}");
             }
             uri_path.to_str().unwrap().to_string()
         };
 
         // read the first column into a HashSet
         let mut enum_set = HashSet::with_capacity(50);
-        let rconfig = Config::new(&Some(dynenum_path));
+        let rconfig = Config::new(Some(dynenum_path).as_ref());
         let mut rdr = rconfig.flexible(true).reader()?;
         for result in rdr.records() {
             match result {
@@ -329,7 +333,7 @@ fn dyn_enum_validator_factory<'a>(
                         enum_set.insert(value.to_owned());
                     }
                 },
-                Err(e) => return fail_validation_error!("Error reading dynenum file - {e}"),
+                Err(e) => return fail_validation_error!("Error reading dynamicEnum file - {e}"),
             };
         }
 
@@ -339,7 +343,7 @@ fn dyn_enum_validator_factory<'a>(
             JsonPointer::default(),
             jsonpointer,
             value,
-            "The 'dynenum' keyword must be set to to a CSV on the local filesystem or on a URL.",
+            "'dynamicEnum' must be set to a CSV file on the local filesystem or on a URL.",
         ))
     }
 }
@@ -352,7 +356,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         Ordering::Relaxed,
     );
 
-    let mut rconfig = Config::new(&args.arg_input).no_headers(args.flag_no_headers);
+    let mut rconfig = Config::new(args.arg_input.as_ref()).no_headers(args.flag_no_headers);
 
     if args.flag_delimiter.is_some() {
         rconfig = rconfig.delimiter(args.flag_delimiter);
@@ -597,15 +601,17 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     // parse and compile supplied JSON Schema
     let (schema_json, schema_compiled): (Value, Validator) =
+        // safety: we know the schema is_some() because we checked above
         match load_json(&args.arg_json_schema.unwrap()) {
             Ok(s) => {
                 // parse JSON string
-                match serde_json::from_str(&s) {
+                let mut s_slice = s.as_bytes().to_vec();
+                match simd_json::serde::from_slice(&mut s_slice) {
                     Ok(json) => {
                         // compile JSON Schema
                         match Validator::options()
                             .with_format("currency", currency_format_checker)
-                            .with_keyword("dynenum", dyn_enum_validator_factory)
+                            .with_keyword("dynamicEnum", dyn_enum_validator_factory)
                             .should_validate_formats(true)
                             .build(&json)
                         {
@@ -643,42 +649,38 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut invalid_count: u64 = 0;
 
     // amortize memory allocation by reusing record
-    let mut record = csv::ByteRecord::new();
+    let mut record = csv::ByteRecord::with_capacity(500, header_len);
+
+    // set RAYON_NUM_THREADS
+    let num_jobs = util::njobs(args.flag_jobs);
+
     // reuse batch buffer
-    let batch_size = if args.flag_batch == 0 {
-        util::count_rows(&rconfig)? as usize
-    } else {
-        args.flag_batch
-    };
+    let batch_size = util::optimal_batch_size(&rconfig, args.flag_batch, num_jobs);
     let mut batch = Vec::with_capacity(batch_size);
     let mut validation_results = Vec::with_capacity(batch_size);
     let mut valid_flags: Vec<bool> = Vec::with_capacity(batch_size);
     let mut validation_error_messages: Vec<String> = Vec::with_capacity(50);
     let flag_trim = args.flag_trim;
 
-    // set RAYON_NUM_THREADS
-    util::njobs(args.flag_jobs);
+    // amortize buffer allocation
+    let mut buffer = itoa::Buffer::new();
 
     // main loop to read CSV and construct batches for parallel processing.
     // each batch is processed via Rayon parallel iterator.
     // loop exits when batch is empty.
     'batch_loop: loop {
-        let mut buffer = itoa::Buffer::new();
         for _ in 0..batch_size {
             match rdr.read_byte_record(&mut record) {
-                Ok(has_data) => {
-                    if has_data {
-                        row_number += 1;
-                        record.push_field(buffer.format(row_number).as_bytes());
-                        if flag_trim {
-                            record.trim();
-                        }
-                        batch.push(std::mem::take(&mut record));
-                    } else {
-                        // nothing else to add to batch
-                        break;
+                Ok(true) => {
+                    row_number += 1;
+                    record.push_field(buffer.format(row_number).as_bytes());
+                    if flag_trim {
+                        record.trim();
                     }
+                    // we use mem::take() to avoid cloning & clearing the record
+                    batch.push(std::mem::take(&mut record));
                 },
+                Ok(false) => break, // nothing else to add to batch
                 Err(e) => {
                     return fail_clierror!("Error reading row: {row_number}: {e}");
                 },
@@ -744,7 +746,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 Some(valid_output)
             };
 
-            let mut valid_wtr = Config::new(&valid_path).writer()?;
+            let mut valid_wtr = Config::new(valid_path.as_ref()).writer()?;
             valid_wtr.write_byte_record(&headers)?;
 
             let mut rdr = rconfig.reader()?;
@@ -816,11 +818,12 @@ fn split_invalid_records(
     let mut split_row_num: usize = 0;
 
     // prepare output writers
-    let mut valid_wtr = Config::new(&Some(input_path.to_owned() + "." + valid_suffix)).writer()?;
+    let mut valid_wtr =
+        Config::new(Some(input_path.to_owned() + "." + valid_suffix).as_ref()).writer()?;
     valid_wtr.write_byte_record(headers)?;
 
     let mut invalid_wtr =
-        Config::new(&Some(input_path.to_owned() + "." + invalid_suffix)).writer()?;
+        Config::new(Some(input_path.to_owned() + "." + invalid_suffix).as_ref()).writer()?;
     invalid_wtr.write_byte_record(headers)?;
 
     let mut rdr = rconfig.reader()?;
@@ -897,15 +900,14 @@ fn do_json_validation(
     )
     .map(|validation_errors| {
         // squash multiple errors into one long String with linebreaks
-        let combined_errors: String = validation_errors
+        validation_errors
             .iter()
-            .map(|tuple| {
+            .map(|(field, error)| {
                 // validation error file format: row_number, field, error
-                format!("{row_number_string}\t{}\t{}", tuple.0, tuple.1)
+                format!("{row_number_string}\t{field}\t{error}")
             })
-            .join("\n");
-
-        combined_errors
+            .collect::<Vec<_>>()
+            .join("\n")
     })
 }
 
@@ -919,27 +921,24 @@ fn to_json_instance(
     let mut json_object_map: Map<String, Value> = Map::with_capacity(header_len);
 
     let mut key_string: String;
-    let mut value_string: String;
-    for ((key_iter, json_type), value) in header_types.iter().zip(record.iter()) {
-        key_string = key_iter.to_owned();
+    for ((key, json_type), value) in header_types.iter().zip(record.iter()) {
+        key_string = key.to_owned();
 
         if value.is_empty() {
             json_object_map.insert(key_string, Value::Null);
             continue;
         }
 
-        let value_str = match simdutf8::basic::from_utf8(value) {
-            Ok(v) => v,
-            Err(e) => {
-                let s = String::from_utf8_lossy(value);
-                return fail_encoding_clierror!("CSV value \"{s}\" is not valid UTF-8: {e}");
-            },
+        let value_str = if let Ok(v) = simdutf8::basic::from_utf8(value) {
+            Cow::Borrowed(v)
+        } else {
+            let s = String::from_utf8_lossy(value);
+            return fail_encoding_clierror!("CSV value \"{s}\" is not valid UTF-8");
         };
 
         match *json_type {
             JSONtypes::String => {
-                value_string = value_str.to_owned();
-                json_object_map.insert(key_string, Value::String(value_string));
+                json_object_map.insert(key_string, Value::String(value_str.into_owned()));
             },
             JSONtypes::Number => {
                 if let Ok(float) = value_str.parse::<f64>() {
@@ -970,6 +969,7 @@ fn to_json_instance(
                 }
             },
             JSONtypes::Unsupported => {
+                // unreachable because we assigned JSONtypes
                 unreachable!("we should never get an unsupported JSON type");
             },
         }
@@ -1195,6 +1195,57 @@ fn validate_json_instance(
     }
 }
 
+fn load_json(uri: &str) -> Result<String, String> {
+    let json_string = match uri {
+        url if url.to_lowercase().starts_with("http") => {
+            use reqwest::blocking::Client;
+
+            let client_timeout =
+                std::time::Duration::from_secs(TIMEOUT_SECS.load(Ordering::Relaxed) as u64);
+
+            let client = match Client::builder()
+                // safety: we're using a validated QSV_USER_AGENT or the default user agent
+                .user_agent(util::set_user_agent(None).unwrap())
+                .brotli(true)
+                .gzip(true)
+                .deflate(true)
+                .zstd(true)
+                .use_rustls_tls()
+                .http2_adaptive_window(true)
+                .connection_verbose(
+                    log_enabled!(log::Level::Debug) || log_enabled!(log::Level::Trace),
+                )
+                .timeout(client_timeout)
+                .build()
+            {
+                Ok(c) => c,
+                Err(e) => {
+                    return fail_format!("Cannot build reqwest client: {e}.");
+                },
+            };
+
+            match client.get(url).send() {
+                Ok(response) => response.text().unwrap_or_default(),
+                Err(e) => return fail_format!("Cannot read JSON at url {url}: {e}."),
+            }
+        },
+        path => {
+            let mut buffer = String::new();
+            match File::open(path) {
+                Ok(p) => {
+                    BufReader::new(p)
+                        .read_to_string(&mut buffer)
+                        .unwrap_or_default();
+                },
+                Err(e) => return fail_format!("Cannot read JSON file {path}: {e}."),
+            }
+            buffer
+        },
+    };
+
+    Ok(json_string)
+}
+
 #[cfg(test)]
 mod tests_for_schema_validation {
     use super::*;
@@ -1280,7 +1331,7 @@ mod tests_for_schema_validation {
 }
 
 #[test]
-fn test_validate_currency_validator() {
+fn test_validate_currency_email_dynamicenum_validator() {
     fn schema_currency_json() -> Value {
         serde_json::json!({
             "$id": "https://example.com/person.schema.json",
@@ -1302,6 +1353,16 @@ fn test_validate_currency_validator() {
                     "description": "The required fee to see the person.",
                     "type": "string",
                     "format": "currency",
+                },
+                "email": {
+                    "description": "The person's email.",
+                    "type": "string",
+                    "format": "email",
+                },
+                "agency": {
+                    "description": "The person's agency.",
+                    "type": "string",
+                    "dynamicEnum": "https://raw.githubusercontent.com/jqnatividad/qsv/refs/heads/master/scripts/NYC_agencies.csv",
                 }
             }
         })
@@ -1321,7 +1382,7 @@ fn test_validate_currency_validator() {
 
     let compiled_schema = Validator::options()
         .with_format("currency", currency_format_checker)
-        .with_keyword("dynenum", dyn_enum_validator_factory)
+        .with_keyword("dynamicEnum", dyn_enum_validator_factory)
         .should_validate_formats(true)
         .build(&schema_currency_json())
         .expect("Invalid schema");
@@ -1337,13 +1398,8 @@ fn test_validate_currency_validator() {
         )])
     );
 
-    let csv = "title,name,fee
-    Professor,Xaviers,USD60.02
-    He-man,Wolverine,$100.00
-    Mr,Deadpool,¥1,000,000.00
-    Mrs,T,-€ 1.000.000,00
-    Madam,X,(EUR 1.999.000,12)
-    It,Vision,1.000.000,00";
+    let csv = "title,name,fee,email
+    Professor,Xaviers,Ð 100.00,thisisnotanemail";
 
     let mut rdr = csv::Reader::from_reader(csv.as_bytes());
     let headers = rdr.byte_headers().unwrap().clone();
@@ -1355,66 +1411,114 @@ fn test_validate_currency_validator() {
 
     let compiled_schema = Validator::options()
         .with_format("currency", currency_format_checker)
-        .with_keyword("dynenum", dyn_enum_validator_factory)
+        .with_keyword("dynamicEnum", dyn_enum_validator_factory)
         .should_validate_formats(true)
         .build(&schema_currency_json())
         .expect("Invalid schema");
 
     let result = validate_json_instance(&instance, &compiled_schema);
 
-    // no validation error for currency format
-    assert_eq!(result, None);
-}
+    assert_eq!(
+        result,
+        Some(vec![
+            (
+                "fee".to_owned(),
+                "\"Ð 100.00\" is not a \"currency\"".to_owned()
+            ),
+            (
+                "email".to_owned(),
+                "\"thisisnotanemail\" is not a \"email\"".to_owned()
+            )
+        ])
+    );
 
-fn load_json(uri: &str) -> Result<String, String> {
-    let json_string = match uri {
-        url if url.to_lowercase().starts_with("http") => {
-            use reqwest::blocking::Client;
+    let csv = r#"title,name,fee,email,agency
+    Professor,Xaviers,"USD60.02",x@men.com,DOITT
+    He-man,Wolverine,"$100.00",claws@men.com,DPR
+    Mr,Deadpool,"¥1,000,000.00",landfill@nomail.net,DSNY
+    Mrs,T,"-€ 1.000.000,00",t+sheher@t.com,MODA
+    Madam,X,"(EUR 1.999.000,12)",x123@aol.com,DOB
+    SilicoGod,Vision,"1.000.000,00",singularity+is@here.ai,DOITT
+    Dr,Strange,"€ 1.000.000,00",stranger.danger@xmen.com,NYFD
+    Dr,Octopus,"WAX 100.000,00",octopussy@bond.net,DFTA
+    Mr,Robot,"B 1,000,000",71076.964-compuserve,ABCD"#;
 
-            let client_timeout =
-                std::time::Duration::from_secs(TIMEOUT_SECS.load(Ordering::Relaxed) as u64);
+    let mut rdr = csv::Reader::from_reader(csv.as_bytes());
+    let headers = rdr.byte_headers().unwrap().clone();
+    let header_types = get_json_types(&headers, &schema_currency_json()).unwrap();
 
-            let client = match Client::builder()
-                // safety: we're using a validated QSV_USER_AGENT or if it's not set,
-                .user_agent(util::set_user_agent(None).unwrap())
-                .brotli(true)
-                .gzip(true)
-                .deflate(true)
-                .zstd(true)
-                .use_rustls_tls()
-                .http2_adaptive_window(true)
-                .connection_verbose(
-                    log_enabled!(log::Level::Debug) || log_enabled!(log::Level::Trace),
-                )
-                .timeout(client_timeout)
-                .build()
-            {
-                Ok(c) => c,
-                Err(e) => {
-                    return fail_format!("Cannot build reqwest client: {e}.");
-                },
-            };
+    let compiled_schema = Validator::options()
+        .with_format("currency", currency_format_checker)
+        .with_keyword("dynamicEnum", dyn_enum_validator_factory)
+        .should_validate_formats(true)
+        .build(&schema_currency_json())
+        .expect("Invalid schema");
 
-            match client.get(url).send() {
-                Ok(response) => response.text().unwrap_or_default(),
-                Err(e) => return fail_format!("Cannot read JSON at url {url}: {e}."),
-            }
-        },
-        path => {
-            let mut buffer = String::new();
-            match File::open(path) {
-                Ok(p) => {
-                    BufReader::new(p)
-                        .read_to_string(&mut buffer)
-                        .unwrap_or_default();
-                },
-                Err(e) => return fail_format!("Cannot read JSON file {path}: {e}."),
-            }
-            buffer
-        },
-    };
+    for (i, record) in rdr.byte_records().enumerate() {
+        let record = record.unwrap();
+        let instance = to_json_instance(&header_types, headers.len(), &record).unwrap();
 
-    Ok(json_string)
+        let result = validate_json_instance(&instance, &compiled_schema);
+
+        match i {
+            0 => assert_eq!(result, None),
+            1 => assert_eq!(result, None),
+            2 => assert_eq!(result, None),
+            3 => assert_eq!(
+                result,
+                Some(vec![
+                    (
+                        "name".to_owned(),
+                        "\"T\" is shorter than 2 characters".to_owned()
+                    ),
+                    (
+                        "agency".to_owned(),
+                        "\"MODA\" is not a valid dynamicEnum value".to_owned()
+                    )
+                ])
+            ),
+            4 => assert_eq!(
+                result,
+                Some(vec![(
+                    "name".to_owned(),
+                    "\"X\" is shorter than 2 characters".to_owned()
+                )])
+            ),
+            5 => assert_eq!(result, None),
+            6 => assert_eq!(
+                result,
+                Some(vec![(
+                    "agency".to_owned(),
+                    "\"NYFD\" is not a valid dynamicEnum value".to_owned()
+                )])
+            ),
+            7 => assert_eq!(
+                result,
+                Some(vec![(
+                    "fee".to_owned(),
+                    "\"WAX 100.000,00\" is not a \"currency\"".to_owned()
+                )])
+            ),
+            8 => assert_eq!(
+                result,
+                Some(vec![
+                    (
+                        "fee".to_owned(),
+                        "\"B 1,000,000\" is not a \"currency\"".to_owned()
+                    ),
+                    (
+                        "email".to_owned(),
+                        "\"71076.964-compuserve\" is not a \"email\"".to_owned()
+                    ),
+                    (
+                        "agency".to_owned(),
+                        "\"ABCD\" is not a valid dynamicEnum value".to_owned()
+                    )
+                ])
+            ),
+            _ => unreachable!(),
+        }
+    }
 }
 
 #[test]
@@ -1429,9 +1533,9 @@ fn test_load_json_via_url() {
 
 #[test]
 fn test_dyn_enum_validator() {
-    let schema = json!({"dynenum": "https://raw.githubusercontent.com/jqnatividad/qsv/refs/heads/master/resources/test/fruits.csv", "type": "string"});
+    let schema = json!({"dynamicEnum": "https://raw.githubusercontent.com/jqnatividad/qsv/refs/heads/master/resources/test/fruits.csv", "type": "string"});
     let validator = jsonschema::options()
-        .with_keyword("dynenum", dyn_enum_validator_factory)
+        .with_keyword("dynamicEnum", dyn_enum_validator_factory)
         .build(&schema)
         .unwrap();
 
@@ -1447,9 +1551,7 @@ fn test_dyn_enum_validator() {
         let err_info = e.into_iter().next().unwrap();
         assert_eq!(
             format!("{err_info:?}"),
-            "ValidationError { instance: String(\"lanzones\"), kind: Custom { message: \"Value \
-             must be a valid dynamic enum\" }, instance_path: JsonPointer([]), schema_path: \
-             JsonPointer([]) }"
+            r#"ValidationError { instance: String("lanzones"), kind: Custom { message: "\"lanzones\" is not a valid dynamicEnum value" }, instance_path: JsonPointer([]), schema_path: JsonPointer([]) }"#
         );
     } else {
         unreachable!("Expected an error, but validation succeeded.");
