@@ -543,8 +543,8 @@ fn excel_metadata() {
             "type",
             "visible",
             "headers",
-            "num_columns",
-            "num_rows",
+            "column_count",
+            "row_count",
             "safe_headers",
             "safe_headers_count",
             "unsafe_headers",
@@ -703,8 +703,10 @@ fn excel_metadata_pretty_json() {
     cmd.arg("--metadata").arg("J").arg(xls_file);
 
     let got: String = wrk.stdout(&mut cmd);
-    let expected: &str = r#""format": "Excel: xls",
-  "num_sheets": 8,
+
+    let expected = r#"excel-xls.xls",
+  "format": "Excel: xls",
+  "sheet_count": 8,
   "sheet": [
     {
       "index": 0,
@@ -715,8 +717,8 @@ fn excel_metadata_pretty_json() {
         "URL",
         "City"
       ],
-      "num_columns": 2,
-      "num_rows": 4,
+      "column_count": 2,
+      "row_count": 4,
       "safe_headers": [
         "URL",
         "City"
@@ -736,8 +738,8 @@ fn excel_metadata_pretty_json() {
         "City",
         ""
       ],
-      "num_columns": 3,
-      "num_rows": 6,
+      "column_count": 3,
+      "row_count": 6,
       "safe_headers": [
         "URL",
         "City"
@@ -758,8 +760,8 @@ fn excel_metadata_pretty_json() {
         "Middle sheet col1",
         "Middle-2"
       ],
-      "num_columns": 2,
-      "num_rows": 6,
+      "column_count": 2,
+      "row_count": 6,
       "safe_headers": [
         "Middle sheet col1",
         "Middle-2"
@@ -775,8 +777,8 @@ fn excel_metadata_pretty_json() {
       "typ": "WorkSheet",
       "visible": "Visible",
       "headers": [],
-      "num_columns": 0,
-      "num_rows": 0,
+      "column_count": 0,
+      "row_count": 0,
       "safe_headers": [],
       "safe_headers_count": 0,
       "unsafe_headers": [],
@@ -793,8 +795,8 @@ fn excel_metadata_pretty_json() {
         "   col2",
         "col3"
       ],
-      "num_columns": 3,
-      "num_rows": 6,
+      "column_count": 3,
+      "row_count": 6,
       "safe_headers": [
         "col1",
         "col3"
@@ -817,8 +819,8 @@ fn excel_metadata_pretty_json() {
         "col_Petsa",
         "just another col"
       ],
-      "num_columns": 4,
-      "num_rows": 6,
+      "column_count": 4,
+      "row_count": 6,
       "safe_headers": [
         "date_col",
         "num_col",
@@ -841,8 +843,8 @@ fn excel_metadata_pretty_json() {
         "col3",
         "col4"
       ],
-      "num_columns": 4,
-      "num_rows": 1,
+      "column_count": 4,
+      "row_count": 1,
       "safe_headers": [
         "col1",
         "col2",
@@ -863,8 +865,8 @@ fn excel_metadata_pretty_json() {
         "Last sheet col1",
         "Last-2"
       ],
-      "num_columns": 2,
-      "num_rows": 6,
+      "column_count": 2,
+      "row_count": 6,
       "safe_headers": [
         "Last sheet col1",
         "Last-2"
@@ -874,7 +876,249 @@ fn excel_metadata_pretty_json() {
       "unsafe_headers_count": 0,
       "duplicate_headers_count": 0
     }
-  ]
+  ],
+  "names": [
+    {
+      "name": "_xlfn._FV",
+      "formula": "Unsupported ptg: 1c"
+    }
+  ],
+  "name_count": 1,
+  "tables": [],
+  "table_count": 0
+}"#;
+    assert!(got.ends_with(expected));
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn excel_metadata_xlsx_ranges_tables_pretty_json() {
+    let wrk = Workdir::new("excel_metadata");
+
+    let xls_file = wrk.load_test_file("excel-xlsx.xlsx");
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg("--metadata").arg("J").arg(xls_file);
+
+    let got: String = wrk.stdout(&mut cmd);
+
+    let expected = r#"excel-xlsx.xlsx",
+  "format": "Excel: xlsx",
+  "sheet_count": 7,
+  "sheet": [
+    {
+      "index": 0,
+      "name": "Sheet1",
+      "typ": "WorkSheet",
+      "visible": "Visible",
+      "headers": [
+        "URL",
+        "City",
+        "number",
+        "date"
+      ],
+      "column_count": 4,
+      "row_count": 9,
+      "safe_headers": [
+        "URL",
+        "City",
+        "number",
+        "date"
+      ],
+      "safe_headers_count": 4,
+      "unsafe_headers": [],
+      "unsafe_headers_count": 0,
+      "duplicate_headers_count": 0
+    },
+    {
+      "index": 1,
+      "name": "safe_header_name_test",
+      "typ": "WorkSheet",
+      "visible": "Visible",
+      "headers": [
+        "col1",
+        "  col with leading and trailing spaces.  ",
+        "123_starts_with_123",
+        "With * / special ? ! Characters. ",
+        "col1",
+        "col1",
+        "The quick BROWN fox with a very long column name is now jumping over a lazy dog by the zigzag quarry site",
+        "!!!date???"
+      ],
+      "column_count": 8,
+      "row_count": 6,
+      "safe_headers": [
+        "col1"
+      ],
+      "safe_headers_count": 1,
+      "unsafe_headers": [
+        "  col with leading and trailing spaces.  ",
+        "123_starts_with_123",
+        "With * / special ? ! Characters. ",
+        "The quick BROWN fox with a very long column name is now jumping over a lazy dog by the zigzag quarry site",
+        "!!!date???"
+      ],
+      "unsafe_headers_count": 5,
+      "duplicate_headers_count": 2
+    },
+    {
+      "index": 2,
+      "name": "date_test",
+      "typ": "WorkSheet",
+      "visible": "Visible",
+      "headers": [
+        "date",
+        "plaincol"
+      ],
+      "column_count": 2,
+      "row_count": 6,
+      "safe_headers": [
+        "date",
+        "plaincol"
+      ],
+      "safe_headers_count": 2,
+      "unsafe_headers": [],
+      "unsafe_headers_count": 0,
+      "duplicate_headers_count": 0
+    },
+    {
+      "index": 3,
+      "name": "data types",
+      "typ": "WorkSheet",
+      "visible": "Visible",
+      "headers": [
+        "int",
+        "float",
+        "bool",
+        "date",
+        "duration",
+        "string",
+        "emojis",
+        "foreign"
+      ],
+      "column_count": 8,
+      "row_count": 6,
+      "safe_headers": [
+        "int",
+        "float",
+        "bool",
+        "date",
+        "duration",
+        "string",
+        "emojis",
+        "foreign"
+      ],
+      "safe_headers_count": 8,
+      "unsafe_headers": [],
+      "unsafe_headers_count": 0,
+      "duplicate_headers_count": 0
+    },
+    {
+      "index": 4,
+      "name": "cellerrors",
+      "typ": "WorkSheet",
+      "visible": "Visible",
+      "headers": [
+        "col1",
+        "col 2",
+        "column-3"
+      ],
+      "column_count": 3,
+      "row_count": 10,
+      "safe_headers": [
+        "col1",
+        "col 2",
+        "column-3"
+      ],
+      "safe_headers_count": 3,
+      "unsafe_headers": [],
+      "unsafe_headers_count": 0,
+      "duplicate_headers_count": 0
+    },
+    {
+      "index": 5,
+      "name": "Sheet2",
+      "typ": "WorkSheet",
+      "visible": "Visible",
+      "headers": [
+        "col1",
+        "col2",
+        "col3",
+        "",
+        "",
+        "",
+        "",
+        "",
+        ""
+      ],
+      "column_count": 9,
+      "row_count": 24,
+      "safe_headers": [
+        "col1",
+        "col2",
+        "col3"
+      ],
+      "safe_headers_count": 3,
+      "unsafe_headers": [
+        "",
+        "",
+        "",
+        "",
+        "",
+        ""
+      ],
+      "unsafe_headers_count": 6,
+      "duplicate_headers_count": 5
+    },
+    {
+      "index": 6,
+      "name": "firstnonemptyrow",
+      "typ": "WorkSheet",
+      "visible": "Visible",
+      "headers": [
+        "col1",
+        "col2",
+        "col3",
+        "col4"
+      ],
+      "column_count": 4,
+      "row_count": 6,
+      "safe_headers": [
+        "col1",
+        "col2",
+        "col3",
+        "col4"
+      ],
+      "safe_headers_count": 4,
+      "unsafe_headers": [],
+      "unsafe_headers_count": 0,
+      "duplicate_headers_count": 0
+    }
+  ],
+  "names": [
+    {
+      "name": "testname",
+      "formula": "cellerrors!$C$6"
+    },
+    {
+      "name": "TestNamedRange",
+      "formula": "Sheet2!$C$20:$E$24"
+    }
+  ],
+  "name_count": 2,
+  "tables": [
+    {
+      "name": "Table1",
+      "sheet": "Sheet2",
+      "columns": [
+        "tabc1",
+        "tabc2",
+        "tabc3"
+      ],
+      "column_count": 3
+    }
+  ],
+  "table_count": 1
 }"#;
     assert!(got.ends_with(expected));
     wrk.assert_success(&mut cmd);
@@ -897,8 +1141,8 @@ fn ods_metadata() {
             "type",
             "visible",
             "headers",
-            "num_columns",
-            "num_rows",
+            "column_count",
+            "row_count",
             "safe_headers",
             "safe_headers_count",
             "unsafe_headers",
@@ -954,9 +1198,9 @@ fn ods_metadata_pretty_json() {
     cmd.arg("--metadata").arg("J").arg(xls_file);
 
     let got: String = wrk.stdout(&mut cmd);
-    let expected: &str = r#"excel-ods.ods",
+    let expected = r#"excel-ods.ods",
   "format": "ODS",
-  "num_sheets": 1,
+  "sheet_count": 1,
   "sheet": [
     {
       "index": 0,
@@ -967,8 +1211,8 @@ fn ods_metadata_pretty_json() {
         "URL",
         "City"
       ],
-      "num_columns": 2,
-      "num_rows": 4,
+      "column_count": 2,
+      "row_count": 4,
       "safe_headers": [
         "URL",
         "City"
@@ -978,9 +1222,15 @@ fn ods_metadata_pretty_json() {
       "unsafe_headers_count": 0,
       "duplicate_headers_count": 0
     }
-  ]
+  ],
+  "names": [],
+  "name_count": 0,
+  "tables": [],
+  "table_count": 0
 }"#;
+
     assert!(got.ends_with(expected));
+    // assert_eq!(got, expected);
     wrk.assert_success(&mut cmd);
 }
 
@@ -1001,8 +1251,8 @@ fn excel_metadata_sheet_types() {
             "type",
             "visible",
             "headers",
-            "num_columns",
-            "num_rows",
+            "column_count",
+            "row_count",
             "safe_headers",
             "safe_headers_count",
             "unsafe_headers",
@@ -1087,8 +1337,8 @@ fn excel_metadata_sheet_types_xlsx() {
             "type",
             "visible",
             "headers",
-            "num_columns",
-            "num_rows",
+            "column_count",
+            "row_count",
             "safe_headers",
             "safe_headers_count",
             "unsafe_headers",
@@ -1167,7 +1417,7 @@ fn excel_metadata_sheet_types_xlsx_short_json() {
     cmd.arg("--metadata").arg("S").arg(xlsx_file);
 
     let got: String = wrk.stdout(&mut cmd);
-    let expected = r#"any_sheets.xlsx","format":"xlsx","num_sheets":4,"sheet":[{"index":0,"name":"Visible","typ":"WorkSheet","visible":"Visible"},{"index":1,"name":"Hidden","typ":"WorkSheet","visible":"Hidden"},{"index":2,"name":"VeryHidden","typ":"WorkSheet","visible":"VeryHidden"},{"index":3,"name":"Chart","typ":"ChartSheet","visible":"Visible"}]}"#;
+    let expected = r#"any_sheets.xlsx","format":"xlsx","sheet_count":4,"sheet":[{"index":0,"name":"Visible","typ":"WorkSheet","visible":"Visible"},{"index":1,"name":"Hidden","typ":"WorkSheet","visible":"Hidden"},{"index":2,"name":"VeryHidden","typ":"WorkSheet","visible":"VeryHidden"},{"index":3,"name":"Chart","typ":"ChartSheet","visible":"Visible"}]}"#;
     assert!(got.ends_with(expected));
     wrk.assert_success(&mut cmd);
 }
@@ -1189,8 +1439,8 @@ fn excel_metadata_sheet_types_xlsb() {
             "type",
             "visible",
             "headers",
-            "num_columns",
-            "num_rows",
+            "column_count",
+            "row_count",
             "safe_headers",
             "safe_headers_count",
             "unsafe_headers",
@@ -1276,8 +1526,8 @@ fn excel_metadata_sheet_types_ods() {
             "type",
             "visible",
             "headers",
-            "num_columns",
-            "num_rows",
+            "column_count",
+            "row_count",
             "safe_headers",
             "safe_headers_count",
             "unsafe_headers",
@@ -1381,7 +1631,7 @@ fn excel_empty_sheet2_message() {
     cmd.arg("--sheet").arg("Sheet1").arg(xls_file);
 
     let got = wrk.output_stderr(&mut cmd);
-    assert_eq!(got, "\"Sheet1\" sheet is empty.\n");
+    assert_eq!(got, "\"Sheet: Sheet1 \"is empty.\n");
     wrk.assert_err(&mut cmd);
 }
 
@@ -1611,3 +1861,88 @@ fn excel_formula_empty_string_value() {
 
     wrk.assert_success(&mut cmd);
 }
+
+#[test]
+fn excel_table_range() {
+    let wrk = Workdir::new("excel_table_range");
+
+    let xlsx_file = wrk.load_test_file("excel-xlsx.xlsx");
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg("--table").arg("Table1").arg(xlsx_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["tabc1", "tabc2", "tabc3"],
+        svec!["a2", "false", "2.2"],
+        svec!["a3", "true", "3.3"],
+        svec!["a4", "true", "4.4"],
+        svec!["a5", "false", "5.56"],
+        svec!["a6", "true", "0.9999"],
+    ];
+
+    assert_eq!(got, expected);
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn excel_named_range() {
+    let wrk = Workdir::new("excel_named_range");
+
+    let xlsx_file = wrk.load_test_file("excel-xlsx.xlsx");
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg("--range").arg("TestNamedRange").arg(xlsx_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["alpha", "1", "5"],
+        svec!["beta", "2.2", "6"],
+        svec!["charlie", "3.3", "7"],
+        svec!["delta", "4.4", "8"],
+        svec!["echo", "5.5", "9"],
+    ];
+
+    assert_eq!(got, expected);
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn excel_absolute_range() {
+    let wrk = Workdir::new("excel_absolute_range");
+
+    let xlsx_file = wrk.load_test_file("excel-xlsx.xlsx");
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg("--range").arg("Sheet2!A1:C3").arg(xlsx_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["col1", "col2", "col3"],
+        svec!["1", "e", "1.1"],
+        svec!["2", "d", "2.2"],
+    ];
+
+    assert_eq!(got, expected);
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn excel_absolute_range2() {
+    let wrk = Workdir::new("excel_absolute_range2");
+
+    let xlsx_file = wrk.load_test_file("excel-xlsx.xlsx");
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg("--range").arg("Sheet2!$A$1:$C$3").arg(xlsx_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["col1", "col2", "col3"],
+        svec!["1", "e", "1.1"],
+        svec!["2", "d", "2.2"],
+    ];
+
+    assert_eq!(got, expected);
+    wrk.assert_success(&mut cmd);
+}
