@@ -24,6 +24,8 @@ fn generate_schema_with_defaults_and_validate_trim_with_no_errors() {
     cmd.arg("adur-public-toilets.csv");
     wrk.output(&mut cmd);
 
+    wrk.assert_success(&mut cmd);
+
     // load output schema file
     let output_schema_string: String =
         wrk.from_str(&wrk.path("adur-public-toilets.csv.schema.json"));
@@ -241,14 +243,15 @@ fn generate_schema_with_defaults_to_stdout() {
     // run schema command
     let mut cmd = wrk.command("schema");
     cmd.arg("adur-public-toilets.csv");
-    let _stdout = wrk.stdout::<String>(&mut cmd);
-    let schema_json_file = wrk
-        .path("adur-public-toilets.csv.schema.json")
-        .to_string_lossy()
-        .into_owned();
-    // load schema_json_file into a string
-    let schema_json = std::fs::read_to_string(&schema_json_file).unwrap();
-    let output_schema_json: Value = serde_json::from_str(&schema_json).unwrap();
+    wrk.output(&mut cmd);
+
+    wrk.assert_success(&mut cmd);
+
+    // load output schema file
+    let output_schema_string: String =
+        wrk.from_str(&wrk.path("adur-public-toilets.csv.schema.json"));
+    let output_schema_json: Value =
+        serde_json::from_str(&output_schema_string).expect("parse schema json");
 
     // diff output json with expected json
     let expected_schema: String =
@@ -257,3 +260,123 @@ fn generate_schema_with_defaults_to_stdout() {
 
     assert_json_eq!(expected_schema_json, output_schema_json);
 }
+
+#[test]
+#[file_serial]
+fn generate_schema_with_const_and_enum_constraints() {
+    // create workspace and invoke schema command with value constraints flag
+    let wrk = Workdir::new("generate_schema_with_const_and_enum_constraints").flexible(true);
+    wrk.clear_contents().unwrap();
+
+    let csv = "first,second,const_col,enum_col
+1,r1,const,alpha
+2,r2,const,beta
+3,r3,const,charlie
+4,r4,const,delta
+5,r5,const,echo
+6,r6,const,foxtrot
+7,r7,const,echo
+8,r8,const,delta
+9,r9,const,charlie
+";
+
+    wrk.create_from_string("enum_const_test.csv", &csv);
+
+    // run schema command with value constraints option
+    let mut cmd = wrk.command("schema");
+    cmd.arg("enum_const_test.csv");
+    cmd.arg("--enum-threshold");
+    cmd.arg("5");
+
+    wrk.assert_success(&mut cmd);
+
+    // load output schema file
+    let output_schema_string: String = wrk.from_str(&wrk.path("enum_const_test.csv.schema.json"));
+    let output_schema_json =
+        serde_json::from_str(&output_schema_string).expect("parse schema json");
+
+    // make sure it's a valid JSON Schema by compiling with jsonschema library
+    jsonschema::Validator::options()
+        .build(&output_schema_json)
+        .expect("valid JSON Schema");
+
+    let expected_schema = r#"{
+  "$schema": "https://json-schema.org/draft-07/schema",
+  "title": "JSON Schema for enum_const_test.csv",
+  "description": "Inferred JSON Schema from QSV schema command",
+  "type": "object",
+  "properties": {
+    "first": {
+      "description": "first column from enum_const_test.csv",
+      "minimum": 1,
+      "maximum": 9,
+      "type": [
+        "integer"
+      ],
+      "enum": [
+        1,
+        2,
+        3,
+        4,
+        5,
+        6,
+        7,
+        8,
+        9
+      ]
+    },
+    "second": {
+      "description": "second column from enum_const_test.csv",
+      "minLength": 2,
+      "maxLength": 2,
+      "type": [
+        "string"
+      ],
+      "enum": [
+        "r1",
+        "r2",
+        "r3",
+        "r4",
+        "r5",
+        "r6",
+        "r7",
+        "r8",
+        "r9"
+      ]
+    },
+    "const_col": {
+      "description": "const_col column from enum_const_test.csv",
+      "minLength": 5,
+      "maxLength": 5,
+      "type": [
+        "string"
+      ],
+      "const": "const"
+    },
+    "enum_col": {
+      "description": "enum_col column from enum_const_test.csv",
+      "minLength": 4,
+      "maxLength": 7,
+      "type": [
+        "string"
+      ],
+      "enum": [
+        "alpha",
+        "beta",
+        "charlie",
+        "delta",
+        "echo",
+        "foxtrot"
+      ]
+    }
+  },
+  "required": [
+    "first",
+    "second",
+    "const_col",
+    "enum_col"
+  ]
+}"#;
+
+    assert_eq!(output_schema_string, expected_schema);
+}
